[igt-dev] [PATCH i-g-t] tests/kms_dp_tiled_display: Increase the time limit to receive all page flips

Karthik B S karthik.b.s at intel.com
Fri Mar 6 04:27:34 UTC 2020


Increasing the time limit from 10us to 20us, within which
page flip events must be received from all the tiles.

Signed-off-by: Karthik B S <karthik.b.s at intel.com>
---
 tests/kms_dp_tiled_display.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/kms_dp_tiled_display.c b/tests/kms_dp_tiled_display.c
index b1160fee..6d19fea6 100644
--- a/tests/kms_dp_tiled_display.c
+++ b/tests/kms_dp_tiled_display.c
@@ -362,9 +362,9 @@ static void page_flip_handler(int fd, unsigned int seq,
 
 	/*
 	 * For seamless tear-free display, the page flip event timestamps
 	 * from all the tiles should not differ by more than 10us.
 	 */
-	igt_fail_on_f(labs(usec) >= 10, "Delayed page flip event from CRTC:%d at %u:%u\n",
+	igt_fail_on_f(labs(usec) >= 20, "Delayed page flip event from CRTC:%d at %u:%u\n",
 		      crtc_id, tv_sec, tv_usec);
 }
 
@@ -362,9 +362,9 @@ static void page_flip_handler(int fd, unsigned int seq,
 	/*
 	 * For seamless tear-free display, the page flip event timestamps
-	 * from all the tiles should not differ by more than 10us.
+	 * from all the tiles should not differ by more than 20us.
 	 */
-- 
2.22.0



More information about the igt-dev mailing list